@@ -69,6 +69,15 @@ class SiteController extends Controller
 	 */
 	public function actionIndex()
 	{
+        if(Yii::app()->getUrlManager()->showScriptName)
+        {
+            $scriptUrl = basename($_SERVER['SCRIPT_NAME']);
+            if(strpos($_SERVER['REQUEST_URI'], $scriptUrl) === false)
+            {
+                header("location: index.php");
+            }
+        }
+
 		$entries = array();
 
 		if(ConfigUtil::getUrlFopen())
@@ -95,27 +104,27 @@ class SiteController extends Controller
 		$this->layout = "login";
 
 		// Languages
-		$availableLanguages = glob('protected/messages/??_??');
-		$currentLanguage = Yii::app()->getLanguage();
+        $languages = array();
+        $files = opendir(Yii::app()->basePath . DIRECTORY_SEPARATOR . 'messages');
+        while($file = readdir($files))
+        {
+            if(preg_match("/^\w\w_\w\w$/", $file))
+            {
+                $languages[] = array(
+                    'label' => Yii::t('language', $file),
+                    'icon' => 'images/language/' . $file . '.png',
+                    'url' => Yii::app()->createUrl('/site/changeLanguage/' . $file),
+                    'htmlOptions' => array('class'=>'icon'),
+                );
+            }
+        }
 
+		$currentLanguage = Yii::app()->getLanguage();
 		if(strlen($currentLanguage) == 2)
 		{
 			$currentLanguage .= '_' . $currentLanguage;
 		}
 
-		$languages = array();
-		foreach($availableLanguages AS $key => $language) 
-		{
-			$full = basename($language);
-
-			$languages[] = array(
-				'label' => Yii::t('language', $full),
-				'icon' => 'images/language/' . $full . '.png',
-				'url' => Yii::app()->createUrl('/site/changeLanguage/' . $full),
-				'htmlOptions' => array('class'=>'icon'),
-			);
-		}
-
 		$availableThemes = Yii::app()->getThemeManager()->getThemeNames();
 		$activeTheme = Yii::app()->getTheme()->getName();
 
@@ -167,7 +176,7 @@ class SiteController extends Controller
 			if($form->validate())
 			{
 				$redirectUrl = $request->getPost("redirectUrl");
-				if($redirectUrl !== null)
+				if($redirectUrl !== null && !StringUtil::endsWith($redirectUrl, "site/login"))
 				{
 					$this->redirect($redirectUrl);
 				}
