@@ -12,7 +12,6 @@
  */
 
 require(dirname(__FILE__).'/YiiBase.php');
-require(dirname(__FILE__).'/../protected/components/ChiveWebApplication.php');
 
 /**
  * Yii is a helper class serving common framework functionalities.
@@ -27,7 +26,7 @@ require(dirname(__FILE__).'/../protected/components/ChiveWebApplication.php');
  */
 
 /**
- * @method ChiveWebApplication app
+ * @method CWebApplication app
  */
 class Yii extends YiiBase
 {
@@ -38,6 +37,6 @@ class Yii extends YiiBase
 	 */
 	public static function createWebApplication($config=null)
 	{
-		return self::createApplication('ChiveWebApplication',$config);		
+		return self::createApplication('CWebApplication',$config);
 	}
 }
\ No newline at end of file
